#PBS -l nodes=8:ppn=4:opteron
#PBS -l walltime=24:0:0
#PBS -e stderr.log
#PBS -o stdout.log

import numpy as np
from ase.io import read
from ase.lattice.tetragonal import SimpleTetragonalFactory
from ase.optimize import QuasiNewton
from gpaw import GPAW, Mixer, FermiDirac, PoissonSolver
from gpaw.utilities import h2gpts
from ase.constraints import FixAtoms

cluster = read('cluster.traj')
minx = cluster.positions[:, 0].min()
miny = cluster.positions[:, 1].min()
cluster.positions[:, 0] -= minx
cluster.positions[:, 1] -= miny


class TiO2Factory(SimpleTetragonalFactory):
        u=0.305
        bravais_basis = [[0, 0, 0],[0.5, 0.5, 0.5],[u, u, 0],[1-u, 1-u, 0],[0.5+u,0.5-u, 0.5],[0.5-u, 0.5+u, 0.5]]
        element_basis = (0, 0, 1, 1, 1, 1)

TiO2 = TiO2Factory()

#TiO2110 surface
system = TiO2(directions= [[1,-1,0],[0,0,-1],[1, 1, 0]],
              size=(2,4,1), symbol=('Ti', 'O'), pbc=(1,1,0),
              latticeconstant={'a':4.6719, 'c':2.9711})
slab = system
pos = slab.get_positions()
# m is 1...N atoms
#n[0] is x, n[2] is z
for m,n in enumerate(pos):
    if n[2] < 0.1:
         pos[m,2]+= system.cell[2,2]

slab.set_positions(pos)


maxz = system.positions[:, 2].max()
minclusterz = cluster.positions[:, 2].min()
cluster.positions[:, 2] += -minclusterz + maxz + 2.0
bridge_oxygen_mask = np.abs(system.positions[:, 2] - maxz) < 0.01
del system[bridge_oxygen_mask]
system += cluster

constraint = FixAtoms(mask=(system.positions[:, 2] < maxz - 0.01))
system.set_constraint(constraint)

system.center(vacuum=6.0, axis=2)
system.positions[:, 2] -= 1.0

calc = GPAW(mode='lcao',
            basis={'Pt': 'dzp', 'Ti': 'sz', 'O': 'sz(dzp)'},
            xc='RPBE',
            gpts=h2gpts(0.2, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS', eps=1e-8),
	    kpts=(2,2,1),
            mixer=Mixer(0.04, 7, 15.0),
            txt='gpaw.txt',
            )

system.set_calculator(calc)

opt = QuasiNewton(system, trajectory='opt.traj', logfile='opt.log')
opt.run(fmax=0.05)
